"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.callDataSource = void 0;
const load_datasources_1 = require("../load-datasources");
const weda_node_sdk_1 = require("@cloudbase/weda-node-sdk");
async function callDataSource(options) {
    const dataSources = await load_datasources_1.loadDataSources();
    let dataSource = dataSources.find(ds => options.dataSourceName === ds.name);
    if (!dataSource) {
        /**
         * 后端创建数据源会有延迟, 可能出现刚创建数据源、添加方法后, 进行测试找不到数据源
         *  故, 若为测试模式, 且找不到数据源对象, 则在此做兼容处理
         */
        if (options.isTestMode) {
            // mock 最基本信息, node-sdk 会根据该信息找对应的的测试数据源信息替换
            dataSource = { name: options.dataSourceName };
        }
        else {
            throw new weda_node_sdk_1.TCBError('UserError.DsNotFound', `找不到数据源${options.dataSourceName}, 或该数据源未正确更新`, {
                reason: `datasource ${options.dataSourceName} not found or not loaded properly, occurred in \`callDataSource\``,
            });
        }
    }
    const result = await weda_node_sdk_1.invokeDataSource(Object.assign(Object.assign({}, options), { dataSource }));
    return result;
}
exports.callDataSource = callDataSource;
